# refgenconf

![Run pytests](https://github.com/refgenie/refgenconf/workflows/Run%20pytests/badge.svg)
[![codecov](https://codecov.io/gh/refgenie/refgenconf/branch/master/graph/badge.svg)](https://codecov.io/gh/refgenie/refgenconf)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/refgenconf/README.html)

Configuration object for [refgenie](https://doi.org/10.1093/gigascience/giz149) *et al.*

Documentation for `refgenconf` can be found with the [primary documentation for refgenie](http://refgenie.databio.org).
